<?php
namespace Ep\Woo\Plugin\Shipping;

use Ep\Wp\Plugin\PluginInterface;

/**
 * Sakriva dostavu koja se naplaćuje ako je dostupna besplatna dostava.
 *
 * @package Ep\Woo\Plugin\Shipping
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/woocommerce
 */
class HideFlatRate implements PluginInterface
{
    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function __invoke(): void
    {
        add_filter('woocommerce_package_rates', [$this, 'wc_package_rates']);
    }

    /**
     * Filtrira metode dostave
     *
     * @param \WC_Shipping_Rate[] $rates
     */
    public function wc_package_rates($rates)
    {
        $hasFreeShipping = false;
        $flatRateKeys = [];

        foreach ($rates as $key => $rate) {
            if ('free_shipping' === $rate->get_method_id()) {
                $hasFreeShipping = true;
            } else if ('flat_rate' === $rate->get_method_id()) {
                $flatRateKeys[] = $key;
            }
        }

        if ($hasFreeShipping) {
            foreach ($flatRateKeys as $key) {
                unset($rates[$key]);
            }
        }

        return $rates;
    }
}